@@ -45,4 +45,4 @@ from .deep_learning.image_classifier import seggregate_data
 from .deep_learning.image_classifier import split_normalize_data
 from .deep_learning.image_classifier import image_classifier
 
-from .datasets._base import load_abdata
\ No newline at end of file
+from .datasets._base import load_data
\ No newline at end of file
